
# ViPErLEED

ViPErLEED is an open-source package for quantitative low-energy electron
diffraction, also known as LEED-*I*(*V*). It comprises tools for measurement,
processing, and analysis of LEED-*I*(*V*) results, calculation of theoretical
*I*(*V*) curves based on a structural model of a surface, and optimization of
such a model to best fit the experimental results.

You can find the full documentation under <https://viperleed.org>.

This repository contains the `viperleed.calc` package, the graphical user
interface (GUI) and the software related to the ViPErLEED electronics.

The ViPErLEED ImageJ plugins are available under
<https://github.com/viperleed/viperleed-imagej>

The TensErLEED back-end code used by `viperleed.calc` is available under
<https://github.com/viperleed/viperleed-tensorleed>

For installation instructions see
<https://viperleed.org/content/installation.html>

For a documentation of the `viperleed` Python API see
<https://viperleed.org/content/api.html>

#### Reporting bugs
You can ask questions, report bugs, and propose new features by creating
a new issue under <https://github.com/viperleed/viperleed/issues>. This
is the preferred means of communication with us.

Alternatively, you can contact us via email at <riva@iap.tuwien.ac.at>.
